@@ -155,6 +155,7 @@ c         ---------------- Error -----------------
        character*50  inpcond
        integer klena,icon, loc
 
+
        open(Ioprim, file=file(1:klena(file) ))
        read(Ioprim, '(a)')  inpcond
        if( index(inpcond, "mul") .gt. 0 ) then
@@ -224,16 +225,17 @@ c                      -1--> EOF
        integer  nf, fc
        integer code, subcode, chg 
        real*8 erg, xin, yin, zin, wx, wy, wz, u, norm
-       character*80 buf
-       character*20 field(11)
+       integer maxfn
+       parameter (maxfn = 13)
+       character*120 buf
+       character*20 field(maxfn)
 
  10    continue
        buf = ' '
        subcode = 0
-
        read(Ioprim, '(a)', end= 100 )  buf
+       call kgetField(buf, field, maxfn, nf)
 
-       call kgetField(buf, field, 11, nf)
        if(nf .eq. 0 )  then
           if( Inpmul .eq. 1) then
              icon = 1
@@ -243,7 +245,7 @@ c            neglect blank line
              goto 10
           endif
        endif
-
+          
        fc = 1
        read(field(fc), *) code
        if(Inpsubcode .eq. 1) then
@@ -264,6 +266,7 @@ c            neglect blank line
           fc = fc + 1
           read( field(fc), *)   zin
        endif
+
        if( Inpdir .gt. 0 ) then
           fc = fc + 1
           read( field(fc), *)   wx
@@ -277,15 +280,19 @@ c              the acuracy of input data may not be enough
           wy = wy/norm
           wz = wz/norm
        endif
+
        if( Inptime .gt. 0 ) then
           fc = fc + 1
           read( field(fc), *)   aTrack.t 
           aTrack.t = aTrack.t*29.98d0    ! cm (t is nsec)
        endif
+
        if( Inpuser .gt. 0 ) then
           fc = fc + 1
           read( field(fc), *)   aTrack.user
        endif
+
+
 c         check number of field; some redandant field may exist at the last part, so
 c         nf many not be equal to fc. but must be nf >= fc
        if(nf .lt.  fc) then
@@ -368,6 +375,7 @@ c                 init 1 event. (clear arrays etc)
          call epi1ev(jcon)
 
 
+
          if(jcon .ne. 0) then
 c                    jcon=0-->user set the incident
 c                    set incident ptcl(s) by sepics
@@ -376,6 +384,9 @@ c                    set incident ptcl(s) by sepics
          else
             icon = 0       ! this is needed 2004. May 2
          endif
+
+
+
          if(icon .eq. 0) then
 c                  check time using stack area data
             call stimec(icon)
@@ -383,6 +394,7 @@ c                  check time using stack area data
          if(icon .eq. 0) then
 c              time and incident are available  for the generation
 c              generate 1 event
+
             call epgen
 c              end of 1 event
             call epe1ev
@@ -426,6 +438,7 @@ c      *****************
 #include  "ZsepManager.h"
       integer icon  !  output.  0
       icon = 0
+
       if( Inpmul .eq. 1) then
 c            multiple particles are incident; icon = 1--> end of a bunch
          do while ( icon .eq. 0 )
@@ -481,6 +494,10 @@ c               fix angle
          if(Inpdir .eq. 0) then
             call sfixa(aTrack)
          endif
+c/////////////
+c         write(0,*) ' pos=',PosInp.x, PosInp.y, PosInp.z
+c         write(0,*) ' ang=', DCInp.x, DCInp.y, DCInp.z
+c///////////
          if(Inpxyz .eq. 0.) then
             if(InputP .eq. 'fix') then
                aTrack.pos=PosInp
